@@ -43,6 +43,7 @@ from haiway.helpers import (
     LoggerObservability,
     asynchronous,
     cache,
+    cache_externally,
     concurrently,
     execute_concurrently,
     process_concurrently,
@@ -53,6 +54,7 @@ from haiway.helpers import (
     timeout,
 )
 from haiway.types import (
+    META_EMPTY,
     MISSING,
     Alias,
     BasicValue,
@@ -61,6 +63,9 @@ from haiway.types import (
     Description,
     Immutable,
     Map,
+    Meta,
+    MetaTags,
+    MetaValues,
     Missing,
     RawValue,
     Specification,
@@ -70,20 +75,12 @@ from haiway.types import (
     unwrap_missing,
 )
 from haiway.utils import (
-    META_EMPTY,
     AsyncQueue,
     AsyncStream,
-    Meta,
-    MetaTags,
-    MetaValue,
-    MetaValues,
-    always,
     as_dict,
     as_list,
     as_set,
     as_tuple,
-    async_always,
-    async_noop,
     getenv,
     getenv_base64,
     getenv_bool,
@@ -91,7 +88,6 @@ from haiway.utils import (
     getenv_int,
     getenv_str,
     load_env,
-    noop,
     setup_logging,
     without_missing,
 )
@@ -131,7 +127,6 @@ __all__ = (
     "Map",
     "Meta",
     "MetaTags",
-    "MetaValue",
     "MetaValues",
     "Missing",
     "MissingContext",
@@ -153,15 +148,13 @@ __all__ = (
     "Validator",
     "Verifier",
     "Verifying",
-    "always",
     "as_dict",
     "as_list",
     "as_set",
     "as_tuple",
-    "async_always",
-    "async_noop",
     "asynchronous",
     "cache",
+    "cache_externally",
     "concurrently",
     "ctx",
     "execute_concurrently",
@@ -173,7 +166,6 @@ __all__ = (
     "getenv_str",
     "is_missing",
     "load_env",
-    "noop",
     "not_missing",
     "process_concurrently",
     "retry",
