@@ -1,8 +1,9 @@
 from haiway.attributes.annotations import AttributeAnnotation
+from haiway.attributes.attribute import Attribute
 from haiway.attributes.coding import AttributesJSONEncoder
 from haiway.attributes.path import AttributePath
 from haiway.attributes.requirement import AttributeRequirement
-from haiway.attributes.state import Attribute, State
+from haiway.attributes.state import State
 from haiway.attributes.validation import (
     Validating,
     ValidationContext,
